@@ -1,6 +1,6 @@
 #' Apply a list of functions sequentially
 #'
-#' This function applies the first function to \code{value}, then the
+#' This function applies the first function to `value`, then the
 #' next function to the result of the previous function call, etc. 
 #' 
 #' @param value initial value.
@@ -9,14 +9,19 @@
 #'
 #'
 #' @export
-freduce <- function(value, function_list)
-{
+freduce <- function(value, function_list) {
   k <- length(function_list)
   if (k > 1) {
     for (i in 1:(k - 1L)) {
-      value <- function_list[[i]](value)  
+      value <- function_list[[i]](value)
     }
   }
+
   value <- withVisible(function_list[[k]](value))
-  if (value[["visible"]]) value[["value"]] else invisible(value[["value"]])
+
+  if (value[["visible"]]) {
+    value[["value"]]
+  } else {
+    invisible(value[["value"]])
+  }
 }
